@@ -306,6 +306,8 @@ class DBConnect:
                 else:
                     # 查询值模糊匹配的结果
                     if filter_value.strip() != '':
+                        filter_value = filter_value.replace("(","\(")
+                        filter_value = filter_value.replace(")","\)")
                         find_dict[filter_key] = {'$regex': filter_value}
             # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
             if start_date and end_date:
